@@ -1,6 +1,7 @@
 from __builtin__ import all as _all, any as _any
+from operator import itemgetter, methodcaller
 from collections import Mapping, Set, Iterable, Iterator, defaultdict
-from itertools import ifilter, imap, chain
+from itertools import ifilter, imap, chain, tee
 
 from .funcs import partial, complement
 from .seqs import take
@@ -9,7 +10,8 @@ from .seqs import take
 __all__ = ['empty', 'iteritems', 'join', 'merge',
            'walk', 'walk_keys', 'walk_values', 'select', 'select_keys', 'select_values',
            'is_distinct', 'all', 'any', 'none', 'one', 'some',
-           'zipdict', 'flip', 'project']
+           'zipdict', 'flip', 'project',
+           'where', 'pluck', 'invoke']
 
 
 ### Generic ops
@@ -17,21 +19,28 @@ def _factory(coll):
     # Hack for defaultdicts overriden constructor
     if isinstance(coll, defaultdict):
         return partial(defaultdict, coll.default_factory)
+    elif isinstance(coll, basestring):
+        return ''.join
     else:
         return coll.__class__
 
 def empty(coll):
     return _factory(coll)()
 
+# TODO: not_empty/non_empty working with iterators?
+#       kinda bool(iterator)
+# NOTE: should I add it to seqs or even data?
+
 def iteritems(coll):
     return coll.iteritems() if hasattr(coll, 'iteritems') else coll
 
 
 def join(colls):
-    it = iter(colls)
+    colls, colls_copy = tee(colls)
+    it = iter(colls_copy)
     dest = next(it, None)
     if dest is None:
-        raise TypeError('join needs at least one collection or string')
+        return None
     cls = dest.__class__
 
     if isinstance(dest, basestring):
@@ -111,6 +120,10 @@ def some(pred, coll=None):
         return some(None, pred)
     return next(ifilter(pred, coll), None)
 
+# TODO: a variant of some that returns mapped value,
+#       one can use some(imap(f, seq)) or first(ikeep(f, seq)) for now.
+#       Call it `find`?
+
 # TODO: vector comparison tests - ascending, descending and such
 
 # TODO: capabilities + type tests or skip?
@@ -123,3 +136,17 @@ def flip(mapping):
 
 def project(mapping, keys):
     return _factory(mapping)((k, mapping[k]) for k in keys if k in mapping)
+
+
+def where(mappings, **cond):
+    match = lambda m: all(m[k] == v for k, v in cond.items())
+    return filter(match, mappings)
+
+# NOTE: should I change params order to be more consistent with map/filter
+#       or leave as is to be consistent with where/invoke?
+def pluck(mappings, key):
+    return map(itemgetter(key), mappings)
+
+
+def invoke(objects, name, *args, **kwargs):
+    return map(methodcaller(name, *args, **kwargs), objects)
