@@ -4,15 +4,16 @@ from collections import defaultdict
 from .funcs import complement
 
 
-__all__ = ['count', 'repeat', 'repeatedly', 'iterate',
-           'take', 'drop', 'first', 'rest',
+__all__ = ['count', 'cycle', 'repeat', 'repeatedly', 'iterate',
+           'take', 'drop', 'first', 'second', 'rest',
            'imap', 'ifilter', 'remove', 'iremove', 'keep', 'ikeep',
            'concat', 'iconcat', 'cat', 'icat', 'mapcat', 'imapcat',
            'izip', 'interleave', 'interpose', 'distinct',
-           'dropwhile', 'takewhile', 'isplit', 'split', 'groupby', 'partition', 'chunks']
+           'dropwhile', 'takewhile', 'split', 'split_at', 'split_by',
+           'group_by', 'partition', 'chunks']
 
 
-from itertools import count, repeat
+from itertools import count, cycle, repeat
 
 def repeatedly(f, n=None):
     _repeat = repeat(None, n) if n else repeat(None)
@@ -24,8 +25,8 @@ def iterate(f, x):
         x = f(x)
 
 
-def take(n, coll):
-    return list(islice(coll, n))
+def take(n, seq):
+    return list(islice(seq, n))
 
 def drop(n, seq):
     return islice(seq, n, None)
@@ -42,11 +43,9 @@ def rest(seq):
 
 # TODO: tree-seq equivalent
 
-def remove(pred, coll):
-    return filter(complement(pred), coll)
-
-def iremove(pred, coll):
-    return ifilter(complement(pred), coll)
+def remove(pred, seq):
+    return list(iremove(pred, seq))
+iremove = ifilterfalse
 
 def keep(f, seq=None):
     if seq is None:
@@ -60,19 +59,19 @@ def ikeep(f, seq=None):
     else:
         return ifilter(bool, imap(f, seq))
 
-def concat(*colls):
-    return list(chain(*colls))
+def concat(*seqs):
+    return list(chain(*seqs))
 iconcat = chain
 
-def cat(colls):
-    return list(icat(colls))
+def cat(seqs):
+    return list(icat(seqs))
 icat = chain.from_iterable
 
-def mapcat(f, *colls):
-    return cat(imap(f, *colls))
+def mapcat(f, *seqs):
+    return cat(imap(f, *seqs))
 
-def imapcat(f, *colls):
-    return icat(imap(f, *colls))
+def imapcat(f, *seqs):
+    return icat(imap(f, *seqs))
 
 def interleave(*seqs):
     return icat(izip(*seqs))
@@ -89,18 +88,32 @@ def distinct(seq):
     seen = set()
     return [x for x in seq if x not in seen and not seen.add(x)]
 
-def isplit(at, seq):
+def isplit(pred, seq):
     a, b = tee(seq)
-    if callable(at):
-        return ifilter(at, a), ifilterfalse(at, b)
-    else:
-        return islice(a, at), islice(b, at, None)
+    return ifilter(pred, a), ifilterfalse(pred, b)
+
+def split(pred, seq):
+    return map(list, isplit(pred, seq))
+
+def isplit_at(n, seq):
+    a, b = tee(seq)
+    return islice(a, n), islice(b, n, None)
+
+def split_at(n, seq):
+    return map(list, isplit_at(n, seq))
+
+def isplit_by(pred, seq):
+    a, b = tee(seq)
+    return takewhile(pred, a), dropwhile(pred, b)
+
+def split_by(pred, seq):
+    return map(list, isplit_by(pred, seq))
 
-def split(at, seq):
-    return map(list, isplit(at, seq))
 
 # NOTE: should I name it cluster? to distinguish from itertools.groupby
-def groupby(f, seq):
+#       or just group?
+# NOTE: should it return OrderedDict to preserve order of keys not just values?
+def group_by(f, seq):
     result = defaultdict(list)
     for item in seq:
         result[f(item)].append(item)
